======
Pyrobo
======


.. image:: https://img.shields.io/pypi/v/pyrobo.svg
        :target: https://pypi.python.org/pypi/pyrobo

.. image:: https://img.shields.io/travis/nicoguaro/pyrobo.svg
        :target: https://travis-ci.org/nicoguaro/pyrobo

.. image:: https://readthedocs.org/projects/pyrobo/badge/?version=latest
        :target: https://pyrobo.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Pyrobo contiene frases de la película colombiana La vendedora de rosas
de Víctor Gaviria, basada en el cuento La vendedora de cerillas
(The little match girl) de Hans Christian Andersen.

* Software libre: licencia MIT
* Documentación: https://pyrobo.readthedocs.io


Créditos
--------

Este paquete fue creado con Cookiecutter_ y la plantilla de proyecto de
`audreyr/cookiecutter-pypackage`_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
